@@ -1,15 +1,15 @@
 ﻿import psycopg2
-from psycopg2 import sql
 import os
 import csv
 import io
 from dotenv import load_dotenv
 
-def export_data_to_csv(credential_file_path, export_file_path):
+def export_data_to_csv(export_file_path):
     """
     The function will export data based on SQL query into csv file.
-    Either use VPN or make sure your IP is whitelisted.
-    For data loading, create a file named: "credentials.env" which has database credential details in following format:
+    You can connect to Database either via credentials.env file or through environment variables.
+    Either use VPN or make sure your IP is whitelisted. 
+    For data loading via credentails file create a file named: "credentials.env" which has database credential details in following format:
         DATABASE = 'database_name'
         USER = 'user_name'
         PASSWORD = 'password'
@@ -17,12 +17,45 @@ def export_data_to_csv(credential_file_path, export_file_path):
         PORT = 'port_number'
   
     Parameters:
-        credential_file_path (string): File Path for Credential File with file name.
         export_file_path (string): File Path to export the data with file name.
     Example:
         export_data_to_csv("D:\\\\Analysis\\\\Occassion Analysis\\\\credentials.env","C:\\\\Analysis\\\\Occassion Analysis\\\\test\\\\occasion.csv")
     """
-    load_dotenv(credential_file_path)
+    def database_connection():
+
+        variables_input = input('Please select DB Credentials input type(ONLY INPUT NUMBER):\n1 Credentials File\n2 Environment Variables\n')
+
+        if int(variables_input) == 1:
+            credential_file_path = input('Enter file path for .env file with file name: ')
+            load_dotenv(credential_file_path)
+            dbname = os.getenv('DATABASE')
+            host = os.getenv('HOST')
+            port = os.getenv('PORT')
+            user = os.getenv('USER')
+            password = os.getenv('PASSWORD')
+        elif int(variables_input) == 2:
+            user_variable_input = input("Enter Environment Variable Names as a Dictonary List in below format\nUSER: DBUSER, DATABASE: DBASE, HOST: DBHOST, PORT: DBPORT, PASSWORD: DBPWD \n\nTHESE ARE VARIABLE NAMES AND NOT ACTUAL VALUE INPUT\nOTHER THAN : and , MAKE SURE NOT TO ADD ANY SPECIAL CHARACTER (CHECK EXAMPLE):\n")
+            environment_variables = dict(subString.strip().split(":") for subString in user_variable_input.strip().split(","))
+            user = os.environ[environment_variables['USER'].strip()]
+            password = os.environ[environment_variables['PASSWORD'].strip()]
+            host = os.environ[environment_variables['HOST'].strip()]
+            port = int(os.environ[environment_variables['PORT'].strip()])
+            dbname = os.environ[environment_variables['DATABASE'].strip()]
+        else:
+            print("Either no input or wrong input value.")
+            quit()
+
+        try:
+            #establishing the connection
+                conn = psycopg2.connect(
+                    database = dbname, user = user, password = password, host = host, port = port
+                )
+                print("Connection successful")
+                return conn
+        except psycopg2.DatabaseError as e:
+            # Confirm unsuccessful connection and stop program execution.
+            print("Database connection unsuccessful.",e)
+            quit()
 
     #this section is for converting text/symbolic emoticons
     def  emoji_converter(message):
@@ -47,26 +80,11 @@ def export_data_to_csv(credential_file_path, export_file_path):
                 outcome += emojis.get(word, word) + " "
             return outcome
 
-
-    dbname = os.getenv('DATABASE')
-    host = os.getenv('HOST')
-    port = os.getenv('PORT')
-    user = os.getenv('USER')
-    password = os.getenv('PASSWORD')
-
-    try:
-    #establishing the connection
-        conn = psycopg2.connect(
-            database = dbname, user = user, password = password, host = host, port = port
-        )
-        print("Connection successful")
-    except psycopg2.DatabaseError as e:
-        # Confirm unsuccessful connection and stop program execution.
-            print("Database connection unsuccessful.",e)
-            quit()
+    #Calling DB Connection Function
+    sql_conn = database_connection()
 
     #Creating a cursor object using the cursor() method
-    cursor = conn.cursor()
+    cursor = sql_conn.cursor()
 
     #Get Occasion List
     sql_query = ("SELECT DISTINCT tier_2_use_case from looker.tiered_attributes_new")
@@ -75,16 +93,15 @@ def export_data_to_csv(credential_file_path, export_file_path):
     o_list = list()
     occasion_list.sort()
     i = 0
-    for o_name in occasion_list:
-        i = i+1
-        print((i,o_name[0]))
-        o_list.append((i,o_name[0]))
+    for index,o_name in enumerate(occasion_list,start=1):
+        print((index,o_name[0]))
+        o_list.append((index,o_name[0]))
     
     #Creating Export File
     t_path_n_file = export_file_path 
     occasion_input = input("Enter Occasion Number from the list (only enter number): ")
-    if occasion_input == '' or int(occasion_input) < 1 or int(occasion_input) > i:
-        print('Null Input,quiting')
+    if occasion_input == '' or int(occasion_input) < 1 or int(occasion_input) > len(o_list):
+        print('Either null or wrong input given. Please re-run.')
         quit()
     else:
         occ = o_list[int(occasion_input)-1]
@@ -117,4 +134,4 @@ def export_data_to_csv(credential_file_path, export_file_path):
             print("Error is: ",e)
             quit()
     cursor.close()
-    conn.close()
+    sql_conn.close()
